@@ -34,7 +34,7 @@ namespace KGAPI2 {
  * @author Daniel Vrátil <dvratil@redhat.com>
  * @since 2.0
  */
-class KGAPILATITUDE_EXPORT LocationCreateJob : public KGAPI2::CreateJob
+class KGAPILATITUDE_DEPRECATED_EXPORT LocationCreateJob : public KGAPI2::CreateJob
 {
     Q_OBJECT
 
@@ -55,14 +55,14 @@ class KGAPILATITUDE_EXPORT LocationCreateJob : public KGAPI2::CreateJob
     /**
      * @brief Destructor
      */
-    virtual ~LocationCreateJob();
+    ~LocationCreateJob() override;
 
   protected:
 
     /**
      * @brief KGAPI2::Job::start implementation
      */
-    void start() Q_DECL_OVERRIDE;
+    void start() override;
 
     /**
      * @brief KGAPI2::CreateJob::handleReplyWithItems implementation
@@ -71,7 +71,7 @@ class KGAPILATITUDE_EXPORT LocationCreateJob : public KGAPI2::CreateJob
      * @param rawData
      */
     ObjectsList handleReplyWithItems(const QNetworkReply *reply,
-                                             const QByteArray& rawData) Q_DECL_OVERRIDE;
+                                             const QByteArray& rawData) override;
 
   private:
     class Private;
