@@ -21,6 +21,7 @@
  */
 
 #include "task.h"
+#include "../debug.h"
 
 using namespace KGAPI2;
 
@@ -32,7 +33,7 @@ class Q_DECL_HIDDEN Task::Private
     Private();
     Private (const Private&);
 
-    bool deleted;
+    bool deleted = false;
 };
 
 Task::Private::Private():
@@ -71,6 +72,25 @@ Task::~Task()
     delete d;
 }
 
+bool Task::operator==(const Task &other) const
+{
+    if (!Object::operator==(other)) {
+        qCDebug(KGAPIDebug) << "Objects don't match";
+        return false;
+    }
+    if (!Todo::operator==(other)) {
+        qCDebug(KGAPIDebug) << "Todos don't match";
+        return false;
+    }
+    if (d->deleted != other.d->deleted) {
+        qCDebug(KGAPIDebug) << "Deleted does not match";
+        return false;
+    }
+
+    return true;
+}
+
+
 void Task::setDeleted(const bool deleted)
 {
     d->deleted = deleted;
